from typing import List

from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.category import Category
from app.schemas.category import CategoryCreate, CategoryUpdate


class CRUDCategory(CRUDBase[Category, CategoryCreate, CategoryUpdate]):
    def get_by_name(self, db: Session, *, name: str) -> Category:
        return db.query(Category).filter(Category.name == name).first()
    
    def get_multi_by_ids(
        self, db: Session, *, ids: List[int], skip: int = 0, limit: int = 100
    ) -> List[Category]:
        return db.query(Category).filter(Category.id.in_(ids)).offset(skip).limit(limit).all()


category = CRUDCategory(Category)